<?php
declare(strict_types=1);

namespace Inti\Wp\Plugin\Container;

use Inti\Container\Exception\MissingDependencyException;
use Inti\Wp\Plugin\Service\PluginManager;
use Inti\Wp\Plugin\Service\PluginRunner;
use Psr\Container\ContainerInterface;

/**
 * Class PluginRunnerFactory
 *
 * @package Inti\Wp\Plugin\Container
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp-plugin
 */
final class PluginRunnerFactory
{
    public function __invoke(ContainerInterface $container): PluginRunner
    {
        if (!$container->has(PluginManager::class)) {
            throw MissingDependencyException::dependencyForService(
                PluginManager::class,
                PluginRunner::class
            );
        }

        return new PluginRunner(
            $container->get(PluginManager::class)
        );
    }
}
